@@ -4,8 +4,10 @@ from io import BytesIO
 from json import loads as json_loads
 from sys import exc_info, version
 from .comment import strip_comment_line_with_symbol, strip_comments  # keep 'unused' imports
-from .encoders import TricksEncoder, json_date_time_encode, class_instance_encode, ClassInstanceEncoder  # keep 'unused' imports
-from .decoders import DuplicateJsonKeyException, TricksPairHook, json_date_time_hook, ClassInstanceHook  # keep 'unused' imports
+from .encoders import TricksEncoder, json_date_time_encode, class_instance_encode, ClassInstanceEncoder, \
+	json_complex_encode  # keep 'unused' imports
+from .decoders import DuplicateJsonKeyException, TricksPairHook, json_date_time_hook, ClassInstanceHook, \
+	json_complex_hook  # keep 'unused' imports
 from json import JSONEncoder
 
 
@@ -48,9 +50,9 @@ def json_nonumpy_obj_hook(dct):
 
 
 _cih_instance = ClassInstanceHook()
-DEFAULT_ENCODERS = (json_date_time_encode, class_instance_encode,)
+DEFAULT_ENCODERS = (json_date_time_encode, class_instance_encode, json_complex_encode,)
 DEFAULT_NONP_ENCODERS = DEFAULT_ENCODERS + (nonumpy_encode,)
-DEFAULT_NONP_HOOKS = (json_nonumpy_obj_hook, json_date_time_hook, _cih_instance,)
+DEFAULT_NONP_HOOKS = (json_nonumpy_obj_hook, json_date_time_hook, _cih_instance, json_complex_hook,)
 
 
 def dumps(obj, sort_keys=None, cls=TricksEncoder, obj_encoders=DEFAULT_NONP_ENCODERS, extra_obj_encoders=(),
